<#
	.SYNOPSIS
		Get-IAzDBAlertRules
	.DESCRIPTION
		Get Azure SQL DB alert rules
	.PARAMETER resourceGroupName
		Azure Resource Group Name
	.EXAMPLE
		.\Get-IAzDBAlertRules -resourceGroupName MyResource
	.INPUTS
	.OUTPUTS
		List of configured alert rules for a given Azure Resource Group
	.NOTES
	.LINK
		https://docs.microsoft.com/en-us/powershell/module/az.resources/get-azresource
		https://docs.microsoft.com/en-us/powershell/module/az.monitor/get-azalertrule
#>

param
(
       [string]$resourceGroupName = "$(Read-Host 'Resource Group Name')"
)

begin {
	if (Get-InstalledModule -Name Az) {
		# You are good to go!
	} else {
		Throw "The Idera Azure SQLDB scripts require the Az module to be installed. See Initialize-IAz PowerShell script to install it."
	}

    # Login to Azure Resource Management Account if not already logged in
	Try {
		$result = Get-AzContext -ErrorAction Continue
		If ($null -eq $result.Account) {
			Login-AzAccount
		}
	} Catch [System.Management.Automation.PSInvalidOperationException] {
		Login-AzAccount
	}
}
process {
	try {
        # Get resource id
        $resourceId = (Get-AzResource -ResourceGroupName $resourceGroupName -ResourceName "$serverName/$databaseName").ResourceID

        # Get alert rules
        $results = Get-AzAlertRule -ResourceGroupName $resourceGroupName -TargetResourceId $resourceId -DetailedOutput

		Write-Output $results
	}
	catch [Exception] {
		Write-Error $Error[0]
		$err = $_.Exception
		while ( $err.InnerException ) {
			$err = $err.InnerException
			Write-Output $err.Message
		}
	}
}
