<#
	.SYNOPSIS
		Get-IAzDBProperties
	.DESCRIPTION
		Get Azure SQL DB properties
	.PARAMETER resourceGroupName
		Azure Resource Group Name
	.PARAMETER serverName
		Azure SQL Server Name
	.EXAMPLE
		.\Get-IAzDBProperties -resourceGroupName MyResource -serverName MyServer
	.INPUTS
	.OUTPUTS
		Database properties for a given server
	.NOTES
	.LINK
		https://docs.microsoft.com/en-us/powershell/module/az.sql/get-azsqldatabase
#>

param
(
       [string]$resourceGroupName = "$(Read-Host 'Resource Group Name')",
       [string]$serverName = "$(Read-Host 'SQL Server Name')"
)

begin {
	if (Get-InstalledModule -Name Az) {
		# You are good to go!
	} else {
		Throw "The Idera Azure SQLDB scripts require the Az module to be installed. See Initialize-IAz PowerShell script to install it."
	}

    # Login to Azure Resource Management Account if not already logged in
	Try {
		$result = Get-AzContext -ErrorAction Continue
		If ($null -eq $result.Account) {
			Login-AzAccount
		}
	} Catch [System.Management.Automation.PSInvalidOperationException] {
		Login-AzAccount
	}
}
process {
	try {
        $results = Get-AzSqlDatabase -ResourceGroupName $resourceGroupName -ServerName $serverName

        Write-Output $results
	}
	catch [Exception] {
		Write-Error $Error[0]
		$err = $_.Exception
		while ( $err.InnerException ) {
			$err = $err.InnerException
			Write-Output $err.Message
		}
	}
}
