<#
	.SYNOPSIS
		Get-IAzSQLDBMetric
	.DESCRIPTION
		Get Azure SQL DB metrics
	.PARAMETER resourceGroupName
		Azure Resource Group Name
	.PARAMETER serverName
		Azure SQL Server Name
	.PARAMETER databaseName
        Azure SQL Database Name
	.EXAMPLE
		.\Get-IAzSQLDBMetric -resourceGroupName MyResource -serverName MyServer -databaseName MyDatabase
	.INPUTS
	.OUTPUTS
		Metrics
	.NOTES
	.LINK
		https://docs.microsoft.com/en-us/powershell/module/az.monitor/get-azmetric
#>

param
(
       [string]$resourceGroupName = "$(Read-Host 'Resource Group Name')",
       [string]$serverName = "$(Read-Host 'SQL Server Name')",
       [string]$databaseName = "$(Read-Host 'Database Name')"
)

begin {
	if (Get-InstalledModule -Name Az) {
		# You are good to go!
	} else {
		Throw "The Idera Azure SQLDB scripts require the Az module to be installed. See Initialize-IAz PowerShell script to install it."
	}

    # Login to Azure Resource Management Account if not already logged in
	Try {
		$result = Get-AzContext -ErrorAction Continue
		If ($null -eq $result.Account) {
			Login-AzAccount
		}
	} Catch [System.Management.Automation.PSInvalidOperationException] {
		Login-AzAccount
	}
}
process {
	try {
        # Get the metrics on the database
        $data = Get-AzMetric -ResourceId "/subscriptions/$($(Get-AzContext).Subscription.Id)/resourceGroups/$resourceGroupName/providers/Microsoft.Sql/servers/$serverName/databases/$databaseName"

		Write-Output $data
	}
	catch [Exception] {
		Write-Error $Error[0]
		$err = $_.Exception
		while ( $err.InnerException ) {
			$err = $err.InnerException
			Write-Output $err.Message
		}
	}
}
