<#
	.SYNOPSIS
		Initialize-IAz
	.DESCRIPTION
		Install/upgrade the PowerShell module for Azure SQL Database
	.EXAMPLE
		.\Initialize-IAz
	.INPUTS
	.OUTPUTS
	.NOTES
		The AzureRm is incompatible with PowerShell 7 and it has been deprecated and will no longer be updated.
		The scripts in this folder are for working with PowerShell 6.2.4 or higher
		You should first uninstall AzureRM. Please refer to the link below for how to do that. 
	.LINK
		Information on the latest Az PowerShell module can be found here:
		   https://docs.microsoft.com/en-us/powershell/azure/new-azureps-module-az?view=azps-2.8.0
		Information on how to remove AzureRM PowerShell module can be found here:
		   https://practicalpowershell.com/remove-azurerm-and-install-az-module-for-azure-powershell-management/
#>

begin {
	try {
		# The latest version of Az which this script installs/updates requires PowerShell v6.2.4 or higher
		#Requires -Version 6.2.4
		if (Get-Module -Name AzureRM* -ListAvailable) {
			Write-Output "It is recommended to first uninstall AzureRM which is deprecated before installing the latest AZ module."
			break
		}

	}
	catch [Exception] {
		Write-Error $Error[0]
		$err = $_.Exception
		while ( $err.InnerException ) {
			$err = $err.InnerException
			Write-Output $err.Message
		}
	}
}
process {
	try {
		if (Get-Module -Name Az -ListAvailable) {
			# If an error occurs trying to update the Az module
			# 	if may have been installed via an MSI installer package
			#  		check the App & features in Windows settings and uninstall it there and rerun this script
			#  		It should be called "Microsoft Azure PowerShell..."
			# If module to be updated is the latest, nothing happens and you will see "skipping..." message
			Update-Module -Name Az -Verbose
		} else {
			Install-Module -Name Az -AllowClobber -Scope CurrentUser -Force
		}

		Import-Module -Name Az

	}
	catch [Exception] {
		Write-Error $Error[0]
		$err = $_.Exception
		while ( $err.InnerException ) {
			$err = $err.InnerException
			Write-Output $err.Message
		}
	}
}

