<#
	.SYNOPSIS
		Set-IAzDBAuditingDisableBlob
	.DESCRIPTION
		Disable Azure SQL DB auditing on a Database
	.PARAMETER resourceGroupName
		Azure Resource Group Name for Storage Account
	.PARAMETER storageAccountName
		Azure storage account name
	.PARAMETER serverName
		Azure SQL Server Name
	.PARAMETER databaseName
		Azure SQL Database Name
	.EXAMPLE
		.\Set-IAzDBAuditingDisableBlob -resourceGroupName MyResource -storageAccountName mystorageaccount
			-servername MyServer -databasename AdventureWorksLTv12 
	.INPUTS
	.OUTPUTS
	.NOTES
	.LINK
		https://docs.microsoft.com/en-us/powershell/module/az.sql/set-azsqldatabaseaudit
#>

param
(
       [string]$resourceGroupName = "$(Read-Host 'Resource Group Name for Storage Account')",
	   [string]$storageAccountName = "$(Read-Host 'Storage Account Name')",
	   [string]$serverName = "$(Read-Host 'SQL Server Name')",
       [string]$databaseName = "$(Read-Host 'Database Name')"
)

begin {
	if (Get-InstalledModule -Name Az) {
		# You are good to go!
	} else {
		Throw "The Idera Azure SQLDB scripts require the Az module to be installed. See Initialize-IAz PowerShell script to install it."
	}

    # Login to Azure Resource Management Account if not already logged in
	Try {
		$result = Get-AzContext -ErrorAction Continue
		If ($null -eq $result.Account) {
			Login-AzAccount
		}
	} Catch [System.Management.Automation.PSInvalidOperationException] {
		Login-AzAccount
	}
}
process {
	try {
		$storageaccount = Get-AzStorageAccount -ResourceGroupName $resourceGroupName -Name $storageAccountName

		# Set an auditing policy
		Write-Verbose "Enabling Database Auditing for $databaseName using Storage Account $storageAccountName."
		Set-AzSqlDatabaseAudit -ResourceGroupName $resourceGroupName -ServerName $serverName -DatabaseName $databaseName `
			-BlobStorageTargetState Disabled -StorageAccountResourceId $storageaccount.id -Confirm

	}
	catch [Exception] {
		Write-Error $Error[0]
		$err = $_.Exception
		while ( $err.InnerException ) {
			$err = $err.InnerException
			Write-Output $err.Message
		}
	}
}

