<#
	.SYNOPSIS
		Set-IAzEnableTDE
	.DESCRIPTION
		Enable Azure SQL DB transparent data encryption
	.PARAMETER resourceGroupName
		Azure Resource Group Name
	.PARAMETER serverName
		Azure SQL Server Name
	.PARAMETER databaseName
		Azure SQL Database Name
	.PARAMETER state
		Enable TDE
	.EXAMPLE
        .\Set-IAzDBEnableTDE -resourceGroupName MyResource -servername MyServer -databasename AdventureWorksLTv12
    .INPUTS
	.OUTPUTS
    .NOTES
	.LINK
		https://docs.microsoft.com/en-us/powershell/module/az.sql/set-azsqldatabasetransparentdataencryption
#>

param
(
       [string]$resourceGroupName = "$(Read-Host 'Resource Group Name')",
	   [string]$serverName = "$(Read-Host 'SQL Server Name')",
       [string]$databaseName = "$(Read-Host 'Database Name')"
)

begin {
	if (Get-InstalledModule -Name Az) {
		# You are good to go!
	} else {
		Throw "The Idera Azure SQLDB scripts require the Az module to be installed. See Initialize-IAz PowerShell script to install it."
	}

    # Login to Azure Resource Management Account if not already logged in
	Try {
		$result = Get-AzContext -ErrorAction Continue
		If ($null -eq $result.Account) {
			Login-AzAccount
		}
	} Catch [System.Management.Automation.PSInvalidOperationException] {
		Login-AzAccount
	}
}
process {
	try {
		# Enabling the database TDE will set the Encryption status to Encrypted
        Set-AzSqlDatabaseTransparentDataEncryption -ResourceGroupName $resourceGroupName -ServerName $serverName -DatabaseName $databaseName -State Enabled -Confirm
	}
	catch [Exception] {
		Write-Error $Error[0]
		$err = $_.Exception
		while ( $err.InnerException ) {
			$err = $err.InnerException
			Write-Output $err.Message
		}
	}
}
