<#
	.SYNOPSIS
		Start-ISqlCheckTable
	.DESCRIPTION
		Run an SMO .CheckTables() against specified server instance and all databases
	.PARAMETER serverInstance
		SQL Server instance
	.EXAMPLE
		.\Start-ISqlCheckTable -serverInstance Server01\SQL2012
	.INPUTS
	.OUTPUTS
		Each database checked
	.NOTES
	.LINK
#>

param (
	[string]$serverInstance = "$(Read-Host 'Server Instance' [e.g. Server01\SQL2012])"
)

begin {
	[void][reflection.assembly]::LoadWithPartialName("Microsoft.SqlServer.Smo")
}
process {
	Write-Verbose "Run a .CheckTables() against specified server instance and all databases..." 

	try {
		# Get a server object for the server instance
		Write-Verbose "Creating SMO Server object for $serverInstance"
		$namedInstance = New-Object Microsoft.SqlServer.Management.Smo.Server ($serverInstance)
		$dbs = $namedInstance.Databases

		foreach ($db in $dbs) {
			# Peform the database check on database name supplied
			#   Repair type set to None with no information messages
			#   Additional repair types include 'AllowDataLoss', 'Fast', 'Rebuild'
			Write-Output "Checking database: $($db.Name)"
			$db.CheckTables('None') 
		}
	}
	catch [Exception] {
		Write-Error $Error[0]
		$err = $_.Exception
		while ( $err.InnerException ) {
			$err = $err.InnerException
			Write-Output $err.Message
		}
	}
}