<#
	.SYNOPSIS
		Invoke-ISqlDatabaseAssessment
	.DESCRIPTION
		Runs a scan on a database using the knowledgebase of checks that flag 
		   security vulnerabilities and highlight deviations from best practices, 
		   such as misconfigurations, excessive permissions, and unprotected sensitive data. 
		   The security checks are based on Microsoft's recommended best practices, 
		   and focus on the security issues that present the biggest risks to your database 
		   and its valuable data. 
		   These security checks also represent many of the requirements from various 
		   regulatory bodies to meet their compliance standards.
	.PARAMETER serverInstance
		SQL Server instance
	.PARAMETER databaseName
		Database name
	.EXAMPLE
		.\Invoke-ISqlDatabaseAssessment -serverInstance MyServer -databaseName AdventureWorks2017
	.INPUTS
	.OUTPUTS
		SQL Assessment scan results
	.NOTES
	.LINK
		https://docs.microsoft.com/en-us/powershell/module/sqlserver/invoke-sqlassessment
#>

param
(
	[string]$serverInstance = "$(Read-Host 'Server Instance [e.g. Server01\SQL2016]')",
	[string]$databaseName = "$(Read-Host 'Database Name [e.g. AdventureWorks2017]')"
)

begin {
}
process {
	try {
		$result = Get-SqlDatabase $databaseName -ServerInstance $serverInstance | Invoke-SqlAssessment		

		Write-Output $result
	}
	catch [Exception] {
		Write-Error $Error[0]
		$err = $_.Exception
		while ( $err.InnerException ) {
			$err = $err.InnerException
			Write-Output $err.Message
		}
	}
}
