<#
	.SYNOPSIS
		Get-ISqlAvailableSQLServers
	.DESCRIPTION
		Get available SQL Server instances
	.EXAMPLE
		.\Get-ISqlAvailableSQLServers
	.INPUTS
		
	.OUTPUTS
		Server names
	.NOTES
		This script is no longer supported in .Net Core used by PowerShell 7x
	.LINK
		
#>

begin {
	[void][reflection.assembly]::LoadWithPartialName("Microsoft.SqlServer.Smo") 
}
process {
	try {
		$psver = $PSVersionTable.PSVersion.Major

		if ($psver -le 5) {
			Write-Verbose "Enumerating servers...please wait"

			# Enumerate servers
			$smoApp = new-object Microsoft.SqlServer.Management.Smo.SmoApplication
			$enumServers = $smoApp::EnumAvailableSqlServers($false) | Select-Object Name
			Write-Output $enumServers
		} else {
			Write-Output "Not supported on versions of PowerShell higher than v5."
		}
	}
	catch [Exception] {
		Write-Error $Error[0]
		$err = $_.Exception
		while ( $err.InnerException ) {
			$err = $err.InnerException
			Write-Output $err.Message
		}
	}
}