<#
	.SYNOPSIS
		Get-ISqlInventory
	.DESCRIPTION
		Get SQL inventory
	.PARAMETER serverName
		Get server name
	.EXAMPLE
		.\Get-ISqlInventory -serverName MyServer
	.INPUTS
	.OUTPUTS
        SQL Instance settings
	.NOTES
	.LINK
#>

param(
    [string]$serverName = "$(Read-Host 'Server name [MyServer]')"
)	

begin {
}
process {
	try {
        $serverName |
            ForEach-Object {Get-ChildItem -Path "SQLSERVER:\SQL\$_"} | 
                Select-Object -Property ComputerNamePhysicalNetBIOS, Name, DisplayName, InstanceName |
                ForEach-Object {
                    If (($_.DisplayName -eq 'Default') -or ($_.DisplayName -eq 'MSSQLSERVER')) {
                       $SQL = $_.name
                    } elseif ($_.InstanceName -ne $NULL) {
                         $SQL = $_.name
                    }

                    New-Object ('Microsoft.SqlServer.Management.Smo.Server') $SQL |
                        Select-Object @{label='ServerName';expression={$_.ComputerNamePhysicalNetBIOS}}, 
                            @{label='InstanceName';expression={$_.Name}},
                            Edition, BuildClrVersionString, BuildNumber, ErrorLogPath, HasNullSaPassword,
                            IsPolyBasedInstalled, IsCaseSensitive, Platform, IsFullTextInstalled, Language,
                            MasterDBLogPath, MasterDBPath, NetName, OSVersion, PhysicalMemory, IsSingleUser,
                            Product, VersionString, Collation, IsClustered, ProductLevel,
                            ComputerNamePhysicalNetBIOS, ResourceLastUpdateDateTime, AuditLevel,
                            BackupDirectory, DefaultFile, DefaultLog, LoginMode, ServiceAccount,
                            ServiceStartMode, State, MailProfile, NamedPipesEnabled
                
	            }
    }    
	catch [Exception] {
		Write-Error $Error[0]
		$err = $_.Exception
		while ( $err.InnerException ) {
			$err = $err.InnerException
			Write-Output $err.Message
		}
	}
}


 