<#
	.SYNOPSIS
		Backup-ISsrsEncryptionKey
	.DESCRIPTION
		Backup reporting services encryption key
	.PARAMETER instance
		Reporting Service instance name
		Default = MSSQLSERVER
	.PARAMETER password
		Password conforming to password length, complexity and history policy
	.EXAMPLE
		.\Backup-ISsrsEncryptionKey -instance SSRS -password PasW0rd!
	.INPUTS
		
	.OUTPUTS
		Creates a file that should be securely stored with password to restore it
	.NOTES
		Must be run on the SQL Server Reporting instance name
	.LINK
		http://technet.microsoft.com/en-us/library/ms157275.aspx
		https://docs.microsoft.com/en-us/sql/reporting-services/tools/rskeymgmt-utility-ssrs?view=sql-server-ver15	
#> 

param (
	[string]$instance = "$(Read-Host 'Reporting Server Instance Name' [e.g. SSRS])",
	[string]$file = "$(Read-Host 'File to store encryption key' [e.g. C:\rsdbkey.snk])",
	[string]$password = "$(Read-Host 'Password for restoring')"
)

Write-Verbose "Backing up Reporting Services encryption key..."

# rskeymgmt binary is located in Reporting Services installation path
#   which will depend on the version of Reporting Services
#   The latest version which is a separate install is in Program Files\Microsoft SQL Server Reporting Services
#   Older versions which are installed as part of SQL Server installation can be found by referencing:
#     https://docs.microsoft.com/en-us/sql/sql-server/install/file-locations-for-default-and-named-instances-of-sql-server?view=sql-server-ver15 

set-location 'c:\Program Files\Microsoft SQL Server Reporting Services\Shared Tools'
.\RSKeyMgmt.exe -e -f $file -p $password -i $instance