<#
	.SYNOPSIS
		Get-ISsrsEventLog
	.DESCRIPTION
		Get newest SSRS Event Log entries
	.PARAMETER newest
		Number of latest records
	.EXAMPLE
		.\Get-ISsrsEventLog -newest 1000
	.INPUTS
	.OUTPUTS
	.NOTES
        The use of Get-WinEvent is compatible on PS v5 and higher
	.LINK
#> 

param (
	[int]$newest = 1000
)

try {
	Write-Verbose "Get newest Event Log Entries for SQL Server Reporting Services ..."

	$SSRSEvents = Get-WinEvent -LogName Application | Where-Object { $_.ProviderName -like 'Report Server*' } | Format-List *
		
	Write-Output $SSRSEvents
}
catch [Exception] {
		Write-Error $Error[0]
		$err = $_.Exception
		while ( $err.InnerException ) {
			$err = $err.InnerException
			Write-Output $err.Message
		}
}