<#
	.SYNOPSIS
		Restore-ISsrsEncryptionKey
	.DESCRIPTION
		Restore reporting services encryption key
	.PARAMETER instance
		Reporting Service instance name
		Default = MSSQLSERVER
	.PARAMETER password
		Password conforming to password length, complexity and history policy
	.EXAMPLE
		.\Restore-ISsrsEncryptionKey -instance SQL2012 -password PasW0rd!
	.INPUTS
	.OUTPUTS
	.NOTES
		Must be run directly on the SQL Server Reporting instance
	.LINK
		http://technet.microsoft.com/en-us/library/ms157275.aspx
		https://docs.microsoft.com/en-us/sql/reporting-services/tools/rskeymgmt-utility-ssrs?view=sql-server-ver15		
#> 

param (
	[string]$instance = "$(Read-Host 'Server Instance Name' [e.g. SQL2012])",
	[string]$file = "$(Read-Host 'File to store encryption key' [e.g. C:\rsdbkey.snk])",
	[string]$password = "$(Read-Host 'Password for restoring')"
)

Write-Verbose "Restoring Reporting Services encryption key..."

# rskeymgmt binary is located in Reporting Services installation path
#   which will depend on the version of Reporting Services
#   The latest version which is a separate install is in Program Files\Microsoft SQL Server Reporting Services
#   Older versions which are installed as part of SQL Server installation can be found by referencing:
#     https://docs.microsoft.com/en-us/sql/sql-server/install/file-locations-for-default-and-named-instances-of-sql-server?view=sql-server-ver15 

set-location 'c:\Program Files\Microsoft SQL Server Reporting Services\Shared Tools'
rskeymgmt -a -f $file -p $password -i $instance