<#
	.SYNOPSIS
		Stop-ISsrsService
	.DESCRIPTION
		Stop SQL Server Reporting Server service for a given instance
	.PARAMETER serverInstance
		SQL Server instance
	.EXAMPLE
		.\Stop-ISsrsService -serverInstance server01\sql2012
	.INPUTS
	.OUTPUTS
	.NOTES
        Requires "Run as Administrator" privileges
	.LINK
#> 

param (
	[string]$serverInstance = "$(Read-Host 'Server Instance' [e.g. server01\sql2012])"
)

begin {
	[void][reflection.assembly]::LoadWithPartialName("Microsoft.SqlServer.Smo")
}
process {
	try {
		$smoServer = new-object Microsoft.SqlServer.Management.Smo.Server $serverInstance
		$ver = $smoServer.Information.VersionMajor 

		if ($ver -ge 15) {
			$service = "SQL Server Reporting Services"
		} else {
			if ($serverInstance.Contains("\")) {
				$instance = $serverInstance.Split("\")[1]
			} else {
				$instance = "MSSQLSERVER"
			}
		
			$service = "SQL Server Reporting Services ($instance)"
		}

		Write-Verbose "Stopping SQL Server Reporting Server service"
		Stop-Service $service
		Write-Output "$service service stopped"
	}
	catch [Exception] {
		Write-Error $Error[0]
		$err = $_.Exception
		while ( $err.InnerException ) {
			$err = $err.InnerException
			Write-Output $err.Message
		}
	}
}