<#
	.SYNOPSIS
		Enable-ISqlTCPProtocol
	.DESCRIPTION
		Enable the TCP protocol
	.PARAMETER serverInstance
		SQL Server instance
	.EXAMPLE
		.\Enable-ISqlTCPProtocol -serverInstance MyServer\SQL2012
	.INPUTS
	.OUTPUTS
	.NOTES
		See https://docs.microsoft.com/en-us/sql/powershell/how-to-enable-tcp-sqlps?view=sql-server-ver15
	.LINK
		
#>

param (
	[string]$serverInstance = "$(Read-Host 'Server Instance' [e.g. Server01\SQL2012])"
)

begin {
	[void][reflection.assembly]::LoadWithPartialName("Microsoft.SqlServer.Smo")
	[void][reflection.assembly]::LoadWithPartialName("Microsoft.SqlServer.SqlWmiManagement")

}
process {
	try {
		$wmi = new-object Microsoft.SqlServer.Management.Smo.Wmi.ManagedComputer

		$instance = $serverInstance.ToUpper().Split("\")[1]

        if($null -eq $instance) {
			$instance = "MSSQLSERVER"
		} else {
			$instance = "MSSQL$" + $instance
		}

		# .GetSmoObject not supported in PowerShell 7
		#$ProtocolUri = "ManagedComputer[@Name='" + $server + "']/ServerInstance[@Name='"+ $instance + "']/ServerProtocol"
		#$tcp = $wmi.getsmoobject($ProtocolUri + "[@Name='Tcp']")

		# Enable the TCP protocol on the default instance.
		$tcp = $wmi.ServerInstances[$instance].ServerProtocols['Tcp']
		$Tcp.IsEnabled = $true
		$Tcp.Alter()
		
		Write-Output $Tcp
	}
	catch [Exception] {
		Write-Error $Error[0]
		$err = $_.Exception
		while ( $err.InnerException ) {
			$err = $err.InnerException
			Write-Output $err.Message
		}
	}
}